"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .paymentmethodsummary_output import (
    PaymentMethodSummaryOutput,
    PaymentMethodSummaryOutputTypedDict,
)
from gr4vy.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PaymentMethodSummariesTypedDict(TypedDict):
    items: List[PaymentMethodSummaryOutputTypedDict]
    r"""A list of items returned for this request."""


class PaymentMethodSummaries(BaseModel):
    items: List[PaymentMethodSummaryOutput]
    r"""A list of items returned for this request."""
